@@ -1,15 +1,13 @@
 use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::Author::ETHER;
-{
-  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.046';
-}
-# git description: v0.045-7-g5a2aa89
-
 BEGIN {
   $Dist::Zilla::PluginBundle::Author::ETHER::AUTHORITY = 'cpan:ETHER';
 }
+# git description: v0.046-4-g0aa0bed
+$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.047';
 # ABSTRACT: A plugin bundle for distributions built by ETHER
+# vim: set ts=8 sw=4 tw=78 et :
 
 use Moose;
 with
@@ -153,10 +151,10 @@ sub configure
         'ManifestSkip',
 
         # Munge Files
-        [ 'Authority'           => { authority => 'cpan:ETHER' } ],
         'Git::Describe',
-        [ PkgVersion            => { ':version' => '4.300036', die_on_existing_version => 1 } ],
-        'PodWeaver',
+        [ PkgVersion            => { ':version' => '5.010', die_on_existing_version => 1, die_on_line_insertion => 1 } ],
+        [ 'Authority'           => { authority => 'cpan:ETHER' } ],
+        [ PodWeaver             => { ':version' => '4.005', replacer => 'replace_with_comment', post_code_replacer => 'replace_with_nothing' } ],
         [ 'NextRelease'         => { ':version' => '4.300018', time_zone => 'UTC', format => '%-8v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
         [ 'ReadmeAnyFromPod'    => { type => 'markdown', filename => 'README.md', location => 'build' } ],
 
@@ -288,7 +286,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
@@ -322,8 +320,13 @@ following F<dist.ini> (following the preamble):
     [ShareDir]
 
 
+    ;;; Finders
+    [FileFinder::ByName / Examples]
+    dir = examples
+
     ;;; Gather Files
     [Git::GatherDir]
+    :version = 2.016
     exclude_filename = README.md
     exclude_filename = LICENSE
     exclude_filename = CONTRIBUTING
@@ -337,12 +340,8 @@ following F<dist.ini> (following the preamble):
     -dist = Dist-Zilla-PluginBundle-Author-ETHER
     -filename = CONTRIBUTING
 
-    [FileFinder::ByName / Examples]
-    dir = examples
-
     [Test::Compile]
     :version = 2.036
-    fail_on_warning = author
     bail_out_on_fail = 1
     xt_mode = 1
     script_finder = :ExecFiles
@@ -355,14 +354,14 @@ following F<dist.ini> (following the preamble):
     [EOLTests]
     [MetaTests]
     [Test::Version]
+    is_strict = 1
     [Test::CPAN::Changes]
+    :version = 0.008
     [Test::ChangesHasContent]
     [Test::UnusedVars]
-
     [Test::MinimumVersion]
     :version = 2.000003
-    max_target_perl = 5.008008
-
+    max_target_perl = 5.008001
     [PodSyntaxTests]
     [PodCoverageTests]
     [Test::PodSpelling]
@@ -375,15 +374,25 @@ following F<dist.ini> (following the preamble):
     [Test::Portability]
 
 
+    ;;; Prune Files
+    [PruneCruft]
+    [ManifestSkip]
+
+
     ;;; Munge Files
-    [Authority]
-    authority = cpan:ETHER
     [Git::Describe]
     [PkgVersion]
-    :version = 4.300036
+    :version = 5.010
     die_on_existing_version = 1
+    die_on_line_insertion = 1
+    [Authority]
+    authority = cpan:ETHER
 
     [PodWeaver]
+    :version = 4.005
+    replacer = replace_with_comment
+    post_code_replacer = replace_with_nothing
+
     [NextRelease]
     :version = 4.300018
     time_zone = UTC
@@ -409,12 +418,15 @@ following F<dist.ini> (following the preamble):
 
     [MetaProvides::Package]
     meta_noindex = 1
+    :version = 1.15000002
+    finder = :InstallModules
 
     [MetaConfig]
 
 
     ;;; Register Prereqs
     [AutoPrereqs]
+    [Prereqs::AuthorDeps]
     [MinimumPerl]
 
     [Prereqs / installer_requirements]
@@ -449,7 +461,7 @@ following F<dist.ini> (following the preamble):
     [Git::Check / initial check]
     allow_dirty =
 
-    ;[Git::CheckFor::MergeConflicts]
+    [Git::CheckFor::MergeConflicts]
 
     [Git::CheckFor::CorrectBranch]
     :version = 0.004
@@ -477,7 +489,7 @@ following F<dist.ini> (following the preamble):
     copy = CONTRIBUTING
 
     [Git::Commit]
-    add_files_in = .
+    add_files_in =
     allow_dirty = Changes
     allow_dirty = README.md
     allow_dirty = LICENSE
